@@ -1303,7 +1303,7 @@ void ConnectionHandler::handleConnection(Socket &peerconn, String &ip)
 				// can't do content filtering on HEAD or redirections (no content)
 				// actually, redirections CAN have content
 				if (!checkme.isItNaughty && (cl != 0) && !ishead) {
-					if ((docheader.isContentType("text") && !isexception) || runav) {
+					if (((docheader.isContentType("text") || docheader.isContentType("-")) && !isexception) || runav) {
 						// don't search the cache if scan_clean_cache disabled & runav true (won't have been cached)
 						// also don't search cache for auth required headers (same reason)
 
@@ -1351,18 +1351,17 @@ void ConnectionHandler::handleConnection(Socket &peerconn, String &ip)
 				exceptionreason = checkme.whatIsNaughtyLog;
 			}
 
-			/*if (docheader.isRedirection()) {
-				checkme.isItNaughty = false;
-			}*/
-
 			if (o.url_cache_number > 0) {
-				// add to cache if: wasn't already there, wasn't naughty, was text,
+				// add to cache if: wasn't already there, wasn't naughty, wasn't allowed by bypass/soft block, was text,
 				// was virus scanned and scan_clean_cache is enabled, was a GET request,
 				// and response was not a set of auth required headers (we haven't checked
-				// the actual content, just the proxy's auth error page!)
-				if (!wasclean && !checkme.isItNaughty
+				// the actual content, just the proxy's auth error page!).
+				// also don't add "not modified" responses to the cache - if someone adds
+				// an entry and does a soft restart, we don't want the site to end up in
+				// the clean cache because someone who's already been to it hits refresh.
+				if (!wasclean && !checkme.isItNaughty && !isbypass
 					&& (docheader.isContentType("text") || (runav && o.scan_clean_cache))
-					&& header.requestType() == "GET" && !docheader.authRequired())
+					&& (header.requestType() == "GET") && (docheader.returnCode() == 200))
 				{
 					addToClean(urld, filtergroup);
 				}
@@ -2242,9 +2241,9 @@ void ConnectionHandler::contentFilter(HTTPHeader *docheader, HTTPHeader *header,
 		system("date");
 #endif
 		if (!checkme->isItNaughty && !checkme->isException && !isbypass && (dblen <= o.max_content_filter_size)
-			&& !docheader->authRequired() && docheader->isContentType("text"))
+			&& !docheader->authRequired() && (docheader->isContentType("text") || docheader->isContentType("-")))
 		{
-			checkme->checkme(docbody, url, domain);  // content filterin
+			checkme->checkme(docbody, url, domain);  // content filtering
 		}
 #ifdef DGDEBUG
 		else {
